@@ -1,11 +1,7 @@
 """mdpo HTML commands related utilities."""
 
-import re
 
-from mdpo.text import removeprefix
-
-
-COMMAND_SEARCH_RE = re.compile(r'<\!\-\-\s{0,}([^\s]+)\s{0,}([\w\s]+)?\-\->')
+COMMAND_SEARCH_REGEX = r'<\!\-\-\s{0,}([^\s]+)\s{0,}([\w\s]+)?\-\->'
 
 MDPO_COMMANDS = [
     'context',
@@ -35,8 +31,12 @@ def parse_mdpo_html_command(value):
         tuple: Namename of the command (not including the ``"mdpo"`` prefix)
         and its value.
     """
-    command_match = COMMAND_SEARCH_RE.search(value)
-    return command_match.groups() if command_match else (None, None)
+    import re
+    command_match = re.compile(COMMAND_SEARCH_REGEX).search(value)
+    if command_match:
+        command, comment = command_match.groups()
+        return (command, comment.rstrip(' ') if comment else None)
+    return (None, None)
 
 
 def normalize_mdpo_command(value):
@@ -53,7 +53,12 @@ def normalize_mdpo_command(value):
     """
     if not value.startswith('mdpo-'):
         value = f'mdpo-{value}'
-    return value if removeprefix(value, 'mdpo-') in MDPO_COMMANDS else None
+    if value.startswith('mdpo-'):
+        return (
+            value if value.split('-', maxsplit=1)[1] in MDPO_COMMANDS
+            else None
+        )
+    return value if value in MDPO_COMMANDS else None
 
 
 def normalize_mdpo_command_aliases(command_aliases):
