@@ -1,55 +1,15 @@
 """Markdown related utilities for mdpo."""
 
-import re
-
 import md4c
+import polib
 
 from mdpo.po import po_escaped_string
 from mdpo.text import min_not_max_chars_in_a_row
 
 
-LINK_REFERENCE_RE = re.compile(
-    r'^\s{0,3}\[([^\]]+)\]:\s+<?([^\s>]+)>?\s*["\'\(]?([^"\'\)]+)?',
+LINK_REFERENCE_REGEX = (
+    r'^\[([^\]]+)\]:\s+<?([^\s>]+)>?\s*["\'\(]?([^"\'\)]+)?'
 )
-LINK_REFERENCED_LINK_RE = re.compile(r'\[([^\]]+)\]\[([^\]\s]+)\]')
-
-
-def escape_links_titles(text, link_start_string='[', link_end_string=']'):
-    r"""Escapes ``"`` characters found inside link titles.
-
-    This is used by mdpo extracting titles of links which contains Markdown
-    `link titles <https://spec.commonmark.org/0.29/#link-title>`_ delimiter
-    characters.
-
-    Args:
-        text (str): Text where the links titles to escape will be searched.
-        link_start_string (str): String that delimites the start of a link.
-        link_end_string (str): String that delimites the end of a link.
-
-    Returns:
-        str: Same text as input with escaped title delimiters characters found
-        inside titles.
-
-    Examples:
-        >>> title = '[a link](href "title with characters to escape "")'
-        >>> escape_links_titles(title)
-        '[a link](href "title with characters to escape \\"")'
-    """
-    link_end_string_escaped_regex = re.escape(link_end_string)
-    regex = re.compile(
-        r'({}[^{}]+{}\([^\s]+\s)([^\)]+)'.format(
-            re.escape(link_start_string),
-            link_end_string_escaped_regex,
-            link_end_string_escaped_regex,
-        ),
-    )
-
-    for match in re.findall(regex, text):
-        original_string = match[0] + match[1]
-        escaped_title = match[1][1:-1].replace('"', '\\"')
-        target_string = f'{match[0]}"{escaped_title}"'
-        text = text.replace(original_string, target_string)
-    return text
 
 
 def parse_link_references(content):
@@ -62,11 +22,15 @@ def parse_link_references(content):
         list: Tuples with 3 values, target, href and title for each link
             reference.
     """
+    import re
+
+    link_reference_re = re.compile(LINK_REFERENCE_REGEX)
+
     response = []
     for line in content.splitlines():
         linestrip = line.strip()
-        if linestrip and linestrip[0] == '[':
-            match = re.search(LINK_REFERENCE_RE, linestrip)
+        if linestrip and linestrip.startswith('['):
+            match = re.search(link_reference_re, linestrip)
             if match:
                 response.append(match.groups())
     return response
@@ -91,8 +55,6 @@ class MarkdownSpanWrapper:
         'code_start_string_escaped',
         'code_end_string',
         'code_end_string_escaped',
-        'link_start_string',
-        'link_end_string',
         'wikilink_start_string',
         'wikilink_end_string',
 
@@ -129,8 +91,6 @@ class MarkdownSpanWrapper:
         self.italic_end_string = kwargs.get('italic_end_string', '*')
         self.code_start_string = kwargs.get('code_start_string', '`')[0]
         self.code_end_string = kwargs.get('code_end_string', '`')[0]
-        self.link_start_string = kwargs.get('link_start_string', '[')
-        self.link_end_string = kwargs.get('link_end_string', ']')
         self.wikilink_start_string = kwargs.get('wikilink_start_string', '[[')
         self.wikilink_end_string = kwargs.get('wikilink_end_string', ']]')
 
@@ -173,7 +133,7 @@ class MarkdownSpanWrapper:
             self._inside_codespan = True
             self._current_line += self.code_start_string
         elif span is md4c.SpanType.A:
-            self._current_line += self.link_start_string
+            self._current_line += '['
             self._current_aspan_href = details['href'][0][1]
             self._current_aspan_title = (
                 details['title'][0][1] if details['title'] else None
@@ -197,7 +157,7 @@ class MarkdownSpanWrapper:
                 self._current_line += f']({self._current_aspan_href}'
                 if self._current_aspan_title:
                     self._current_line += (
-                        f' "{escape_links_titles(self._current_aspan_title)}"'
+                        f' "{polib.escape(self._current_aspan_title)}"'
                     )
                 self._current_line += ')'
             self._current_aspan_href = False
@@ -215,7 +175,7 @@ class MarkdownSpanWrapper:
             self._current_line += f']({src}'
             if details['title']:
                 title = details['title'][0][1]
-                self._current_line += f' "{escape_links_titles(title)}"'
+                self._current_line += f' "{polib.escape(title)}"'
             self._current_line += ')'
 
     def text(self, block, text):
@@ -322,12 +282,17 @@ def solve_link_reference_targets(translations):
     targets will be resolved and returned in a new dictionary.
 
     Args:
-        translations (dictionary): Mapping of msgid-msgstr entries from which
+        translations (dict): Mapping of msgid-msgstr entries from which
             the resolved translations will be extracted.
 
     Returns:
         dict: New created messages with solved link reference targets.
     """
+    import re
+
+    link_refereced_link_re = re.compile(r'\[([^\]]+)\]\[([^\]\s]+)\]')
+    link_reference_re = re.compile(LINK_REFERENCE_REGEX)
+
     solutions = {}
 
     # dictionary with defined link references and their targets
@@ -339,18 +304,18 @@ def solve_link_reference_targets(translations):
 
     # discover link reference definitions
     for msgid, msgstr in translations.items():
-        if msgid[0] == '[':  # filter for performance improvement
-            msgid_match = re.search(LINK_REFERENCE_RE, msgid)
+        if msgid.startswith('['):  # filter for performance improvement
+            msgid_match = re.search(link_reference_re, msgid.lstrip(' '))
             if msgid_match:
-                msgstr_match = re.search(LINK_REFERENCE_RE, msgstr)
+                msgstr_match = re.search(link_reference_re, msgstr.lstrip(' '))
                 if msgstr_match:
                     link_references_text_targets.append((
                         msgid_match.groups(),
                         msgstr_match.groups(),
                     ))
-        msgid_matchs = re.findall(LINK_REFERENCED_LINK_RE, msgid)
+        msgid_matchs = re.findall(link_refereced_link_re, msgid)
         if msgid_matchs:
-            msgstr_matchs = re.findall(LINK_REFERENCED_LINK_RE, msgstr)
+            msgstr_matchs = re.findall(link_refereced_link_re, msgstr)
             if msgstr_matchs:
                 msgid_msgstrs_with_links.append((
                     msgid, msgstr, msgid_matchs, msgstr_matchs,
