@@ -69,9 +69,7 @@ class Md2Po:
         '_leavespan_replacer',
 
         'bold_start_string',
-        'bold_start_string_escaped',
         'bold_end_string',
-        'bold_end_string_escaped',
         'italic_start_string',
         'italic_start_string_escaped',
         'italic_end_string',
@@ -80,8 +78,6 @@ class Md2Po:
         'code_start_string_escaped',
         'code_end_string',
         'code_end_string_escaped',
-        'link_start_string',
-        'link_end_string',
         'strikethrough_start_string',
         'strikethrough_end_string',
         'latexmath_start_string',
@@ -187,14 +183,7 @@ class Md2Po:
 
         if not self.plaintext:
             self.bold_start_string = kwargs.get('bold_start_string', '**')
-            self.bold_start_string_escaped = po_escaped_string(
-                self.bold_start_string,
-            )
-
             self.bold_end_string = kwargs.get('bold_end_string', '**')
-            self.bold_end_string_escaped = po_escaped_string(
-                self.bold_end_string,
-            )
 
             self.italic_start_string = kwargs.get('italic_start_string', '*')
             self.italic_start_string_escaped = po_escaped_string(
@@ -508,14 +497,14 @@ class Md2Po:
                     ' extracted comment with the command'
                     f' \'{original_command}\'.',
                 )
-            self._current_tcomment = comment.rstrip()
+            self._current_tcomment = comment
         elif mdpo_command == 'mdpo-context':
             if not comment:
                 raise ValueError(
                     'You need to specify a string for the'
                     f' context with the command \'{original_command}\'.',
                 )
-            self._current_msgctxt = comment.rstrip()
+            self._current_msgctxt = comment
         elif mdpo_command == 'mdpo-include':
             if not comment:
                 raise ValueError(
@@ -523,7 +512,7 @@ class Md2Po:
                     ' comment to include with the command'
                     f' \'{original_command}\'.',
                 )
-            self._current_msgid = comment.rstrip()
+            self._current_msgid = comment
             self._save_current_msgid()
 
     def _process_command(self, text):
@@ -703,7 +692,7 @@ class Md2Po:
                         self._current_aspan_ref_target = target
                         break
             else:
-                for target, href, title in self._link_references:
+                for target, href, _ in self._link_references:
                     if href == current_aspan_href:
                         self._current_aspan_ref_target = target
                         break
@@ -760,10 +749,11 @@ class Md2Po:
 
         if span is md4c.SpanType.A:
             if self._current_aspan_ref_target:  # referenced link
-                self._current_msgid += (
-                    f'[{self._current_aspan_text}]'
-                    f'[{self._current_aspan_ref_target}]'
-                )
+                self._current_msgid += f'[{self._current_aspan_text}]'
+                if self._current_aspan_ref_target != self._current_aspan_text:
+                    self._current_msgid += (
+                        f'[{self._current_aspan_ref_target}]'
+                    )
                 self._current_aspan_ref_target = None
             else:
                 title = details['title'][0][1] if details['title'] else ''
@@ -771,10 +761,10 @@ class Md2Po:
                     # autolink vs link clash (see implementation notes)
                     self._current_msgid += f'<{self._current_aspan_text}'
                     if title:
-                        self._current_msgid += f' "{title}"'
+                        self._current_msgid += f' "{polib.escape(title)}"'
                     self._current_msgid += '>'
                 else:
-                    title_part = f' "{title}"' if title else ''
+                    title_part = f' "{polib.escape(title)}"' if title else ''
                     href = details['href'][0][1]
                     self._current_msgid += (
                         f'[{self._current_aspan_text}]({href}{title_part})'
@@ -817,7 +807,7 @@ class Md2Po:
             else:
                 img_markup += f'({imgspan_src}'
                 if imgspan_title:
-                    img_markup += f' "{imgspan_title}"'
+                    img_markup += f' "{polib.escape(imgspan_title)}"'
                 img_markup += ')'
 
             self._current_imgspan = {}
@@ -942,7 +932,7 @@ class Md2Po:
                 self.po_filepath = ''
 
         pofile_kwargs = (
-            dict(autodetect_encoding=False, encoding=po_encoding)
+            {'autodetect_encoding': False, 'encoding': po_encoding}
             if po_encoding else {}
         )
         self.pofile = polib.pofile(
@@ -992,13 +982,13 @@ class Md2Po:
                 self._current_top_level_block_number = 0
                 self._current_top_level_block_type = None
 
-        if self.mark_not_found_as_obsolete:
-            mark_not_found_entries_as_obsoletes(
+        if not self.preserve_not_found:
+            remove_not_found_entries(
                 self.pofile,
                 self.found_entries,
             )
-        elif not self.preserve_not_found:
-            remove_not_found_entries(
+        elif self.mark_not_found_as_obsolete:
+            mark_not_found_entries_as_obsoletes(
                 self.pofile,
                 self.found_entries,
             )
