@@ -18,6 +18,7 @@ from mdpo.cli import (
     add_extensions_argument,
     add_nolocation_option,
     add_pre_commit_option,
+    add_wrapwidth_argument,
     cli_codespan,
     parse_command_aliases_cli_arguments,
     parse_metadata_cli_arguments,
@@ -80,13 +81,7 @@ def build_parser():
              f' {cli_codespan("``inline code``")} and'
              f' {cli_codespan("[link](target)")}.',
     )
-    parser.add_argument(
-        '-w', '--wrapwidth', dest='wrapwidth', metavar='N/inf', type=str,
-        default='78',
-        help='Wrap width for po file indicated at'
-             f' {cli_codespan("--po-filepath")} parameter. If negative,'
-             ' \'0\' or \'inf\', the PO file content will not be wrapped.',
-    )
+    add_wrapwidth_argument(parser, markup='po')
     parser.add_argument(
         '-m', '--merge-po-files', '--merge-pofiles',
         dest='mark_not_found_as_obsolete',
@@ -102,7 +97,8 @@ def build_parser():
         help='Messages not found which are already stored in the PO file'
              f' passed as {cli_codespan("--po-filepath")} parameter will be'
              ' removed. Only has effect used in combination with'
-             f' {cli_codespan("--merge-pofiles")}.',
+             f' {cli_codespan("--merge-pofiles")}. If you pass this option,'
+             f' {cli_codespan("--merge-po-files")} will be ignored.',
     )
     add_nolocation_option(parser)
     add_extensions_argument(parser)
@@ -165,13 +161,17 @@ def parse_options(args=[]):
         sys.exit(1)
     opts, unknown = parser.parse_known_args(args)
 
+    files_or_content = ''
     if not sys.stdin.isatty():
-        files_or_content = sys.stdin.read().strip('\n')
+        files_or_content += sys.stdin.read().strip('\n')
     if isinstance(opts.files_or_content, list) and opts.files_or_content:
         if len(opts.files_or_content) == 1:
-            files_or_content = opts.files_or_content[0]
+            files_or_content += opts.files_or_content[0]
         else:
             files_or_content = opts.files_or_content
+    if not files_or_content:
+        sys.stderr.write('Files or content to extract not specified\n')
+        sys.exit(1)
     opts.files_or_content = files_or_content
 
     if opts.extensions is None:
@@ -197,36 +197,36 @@ def run(args=[]):
     with environ(_MDPO_RUNNING='true'):
         opts = parse_options(args)
 
-        init_kwargs = dict(
-            ignore=opts.ignore,
-            plaintext=opts.plaintext,
-            mark_not_found_as_obsolete=opts.mark_not_found_as_obsolete,
-            preserve_not_found=opts.preserve_not_found,
-            location=opts.location,
-            extensions=opts.extensions,
-            xheaders=opts.xheaders,
-            include_codeblocks=opts.include_codeblocks,
-            ignore_msgids=opts.ignore_msgids,
-            command_aliases=opts.command_aliases,
-            metadata=opts.metadata,
-            debug=opts.debug,
-            _check_saved_files_changed=opts.check_saved_files_changed,
-        )
+        init_kwargs = {
+            'ignore': opts.ignore,
+            'plaintext': opts.plaintext,
+            'mark_not_found_as_obsolete': opts.mark_not_found_as_obsolete,
+            'preserve_not_found': opts.preserve_not_found,
+            'location': opts.location,
+            'extensions': opts.extensions,
+            'xheaders': opts.xheaders,
+            'include_codeblocks': opts.include_codeblocks,
+            'ignore_msgids': opts.ignore_msgids,
+            'command_aliases': opts.command_aliases,
+            'metadata': opts.metadata,
+            'debug': opts.debug,
+            '_check_saved_files_changed': opts.check_saved_files_changed,
+        }
 
-        extract_kwargs = dict(
-            po_filepath=opts.po_filepath,
-            save=opts.save,
-            mo_filepath=opts.mo_filepath,
-            po_encoding=opts.po_encoding,
-            md_encoding=opts.md_encoding,
-            wrapwidth=opts.wrapwidth,
-        )
+        extract_kwargs = {
+            'po_filepath': opts.po_filepath,
+            'save': opts.save,
+            'mo_filepath': opts.mo_filepath,
+            'po_encoding': opts.po_encoding,
+            'md_encoding': opts.md_encoding,
+            'wrapwidth': opts.wrapwidth,
+        }
 
         md2po = Md2Po(opts.files_or_content, **init_kwargs)
         pofile = md2po.extract(**extract_kwargs)
 
         if not opts.quiet:
-            sys.stdout.write(f'{pofile}\n')
+            sys.stdout.write(f'{pofile.__unicode__()}\n')
 
         # pre-commit mode
         if opts.check_saved_files_changed and md2po._saved_files_changed:
