@@ -9,6 +9,7 @@ import argparse
 import sys
 
 from mdpo.cli import (
+    SPHINX_IS_RUNNING,
     add_command_alias_argument,
     add_common_cli_first_arguments,
     add_debug_option,
@@ -16,6 +17,7 @@ from mdpo.cli import (
     add_extensions_argument,
     add_nolocation_option,
     add_pre_commit_option,
+    add_wrapwidth_argument,
     parse_command_aliases_cli_arguments,
 )
 from mdpo.context import environ
@@ -41,28 +43,40 @@ def build_parser():
         '-l', '--lang', dest='langs', default=[], action='append',
         help='Language codes used to create the output directories.'
              ' This argument can be passed multiple times.',
-        metavar='LANG',
+        metavar='LANG', required=True,
+    )
+
+    output_paths_schema_help = '' if SPHINX_IS_RUNNING else (
+        ' For example, for the schema \'locale/{lang}\', the languages'
+        ' \'es\' and \'fr\' and a \'README.md\' as input, the next files'
+        ' will be written: \'locale/es/README.po\', \'locale/es/README.md\','
+        ' \'locale/fr/README.po\' and \'locale/fr/README.md\'.'
+        ' Note that you can omit \'{basename}\', specifying a'
+        ' directory for each language with \'locale/{lang}\' for this'
+        ' example.'
     )
     parser.add_argument(
-        '-o', '--output', dest='output_paths_schema',
-        required=True, type=str,
+        '-o', '--output', dest='output_paths_schema', required=True, type=str,
         help='Path schema for outputs, built using placeholders. There is a'
-             ' mandatory placeholder for languages: \'{lang}\'; and one'
-             ' optional for output basename: \'{basename}\'. For example,'
-             ' for the schema \'locale/{lang}\', the languages \'es\' and'
-             ' \'fr\' and a \'README.md\' as input, the next files will be'
-             ' written: \'locale/es/README.po\', \'locale/es/README.md\','
-             ' \'locale/fr/README.po\' and \'locale/fr/README.md\'.'
-             ' Note that you can omit \'{basename}\', specifying a'
-             ' directory for each language with \'locale/{lang}\' for this'
-             ' example. Unexistent directories and files will be created, '
-             ' so you don\'t have to prepare the output directories before'
-             ' the execution.',
+             ' mandatory placeholder for languages: {lang};and one optional'
+             f' for output basename: {{basename}}.{output_paths_schema_help}'
+             ' Unexistent directories and files will be created, so you do not'
+             ' have to prepare the output directories before the execution.',
         metavar='PATH_SCHEMA',
     )
     add_nolocation_option(parser)
     add_extensions_argument(parser)
     add_command_alias_argument(parser)
+    add_wrapwidth_argument(
+        parser,
+        markup='po',
+        markup_prefix=True,
+        short=False,
+        help_to_render='PO files',
+    )
+    add_wrapwidth_argument(
+        parser, markup='md', markup_prefix=True, short=False, default='80',
+    )
     add_encoding_arguments(parser)
     add_debug_option(parser)
     add_pre_commit_option(parser)
@@ -81,6 +95,9 @@ def parse_options(args=[]):
         input_paths_glob += sys.stdin.read().strip('\n')
     if isinstance(opts.input_paths_glob, list) and opts.input_paths_glob:
         input_paths_glob += opts.input_paths_glob[0]
+    if not input_paths_glob:
+        sys.stderr.write('Files or content to translate not specified\n')
+        sys.exit(1)
     opts.input_paths_glob = input_paths_glob
 
     if opts.extensions is None:
@@ -99,20 +116,22 @@ def run(args=[]):
     with environ(_MDPO_RUNNING='true'):
         opts = parse_options(args)
 
-        kwargs = dict(
-            extensions=opts.extensions,
-            command_aliases=opts.command_aliases,
-            debug=opts.debug,
-            location=opts.location,
-            po_encoding=opts.po_encoding,
-            md_encoding=opts.md_encoding,
-        )
+        kwargs = {
+            'extensions': opts.extensions,
+            'command_aliases': opts.command_aliases,
+            'debug': opts.debug,
+            'location': opts.location,
+            'po_wrapwidth': opts.po_wrapwidth,
+            'md_wrapwidth': opts.md_wrapwidth,
+            'po_encoding': opts.po_encoding,
+            'md_encoding': opts.md_encoding,
+            '_check_saved_files_changed': opts.check_saved_files_changed,
+        }
 
         _saved_files_changed = markdown_to_pofile_to_markdown(
             opts.langs,
             opts.input_paths_glob,
             opts.output_paths_schema,
-            _check_saved_files_changed=opts.check_saved_files_changed,
             **kwargs,
         )
         if opts.check_saved_files_changed and _saved_files_changed:
