@@ -204,7 +204,8 @@ class MdPo2HTML(HTMLParser):
 
             elif handle == 'data':
                 if not _inside_code:
-                    handled = re.sub(r'\s{2,}', ' ', handled)
+                    while '  ' in handled:
+                        handled = handled.replace('  ', ' ')
 
                 if all((ch in ALIGNMENT_CHARS) for ch in handled):
                     raw_html_template += handled
@@ -418,7 +419,7 @@ class MdPo2HTML(HTMLParser):
                 elif command == 'mdpo-enable-next-line':
                     self._enable_next_line = True
                 elif command == 'mdpo-context' and comment:
-                    self._current_msgctxt = comment.strip()
+                    self._current_msgctxt = comment
                 elif command == 'mdpo-include-codeblock':
                     warnings.warn(
                         'Code blocks translations are not supported'
