@@ -1,8 +1,5 @@
 """Markdown files translator using PO files as reference."""
 
-import math
-import re
-
 import md4c
 import polib
 
@@ -12,22 +9,14 @@ from mdpo.command import (
 )
 from mdpo.event import debug_events, raise_skip_event
 from mdpo.io import save_file_checking_file_changed, to_file_content_if_is_file
-from mdpo.md import (
-    MarkdownSpanWrapper,
-    escape_links_titles,
-    parse_link_references,
-)
+from mdpo.md import MarkdownSpanWrapper, parse_link_references
 from mdpo.md4c import DEFAULT_MD4C_GENERIC_PARSER_EXTENSIONS
 from mdpo.po import (
     paths_or_globs_to_unique_pofiles,
     po_escaped_string,
     pofiles_to_unique_translations_dicts,
 )
-from mdpo.text import (
-    min_not_max_chars_in_a_row,
-    parse_wrapwidth_argument,
-    removesuffix,
-)
+from mdpo.text import min_not_max_chars_in_a_row, parse_wrapwidth_argument
 
 
 class Po2Md:
@@ -45,9 +34,7 @@ class Po2Md:
         'wrapwidth',
 
         'bold_start_string',
-        'bold_start_string_escaped',
         'bold_end_string',
-        'bold_end_string_escaped',
         'italic_start_string',
         'italic_start_string_escaped',
         'italic_end_string',
@@ -56,8 +43,6 @@ class Po2Md:
         'code_start_string_escaped',
         'code_end_string',
         'code_end_string_escaped',
-        'link_start_string',
-        'link_end_string',
         'wikilink_start_string',
         'wikilink_end_string',
 
@@ -84,7 +69,6 @@ class Po2Md:
         '_inside_hblock',
         '_inside_aspan',
         '_inside_codespan',
-        '_inside_table',
         '_codespan_start_index',
         '_codespan_backticks',
         '_codespan_inside_current_msgid',
@@ -148,7 +132,7 @@ class Po2Md:
         self.wrapwidth = (
             # infinte gives some undesired rendering
             (
-                2 ** 24 if kwargs['wrapwidth'] in [math.inf, 0]
+                2 ** 24 if kwargs['wrapwidth'] in [float('inf'), 0]
                 else parse_wrapwidth_argument(kwargs['wrapwidth'])
             ) if 'wrapwidth' in kwargs else 80
         )
@@ -158,14 +142,7 @@ class Po2Md:
         )
 
         self.bold_start_string = kwargs.get('bold_start_string', '**')
-        self.bold_start_string_escaped = po_escaped_string(
-            self.bold_start_string,
-        )
-
         self.bold_end_string = kwargs.get('bold_end_string', '**')
-        self.bold_end_string_escaped = po_escaped_string(
-            self.bold_end_string,
-        )
 
         self.italic_start_string = kwargs.get('italic_start_string', '*')
         self.italic_start_string_escaped = po_escaped_string(
@@ -225,7 +202,6 @@ class Po2Md:
         self._inside_liblock = False
         # first li block paragraph (li block "title")
         self._inside_liblock_first_p = False
-        self._inside_table = False
 
         self._inside_codespan = False
         self._codespan_start_index = None
@@ -284,9 +260,9 @@ class Po2Md:
             self._enable_next_line = True
         elif comment:
             if mdpo_command == 'mdpo-context':
-                self._current_msgctxt = comment.rstrip()
+                self._current_msgctxt = comment
             elif mdpo_command == 'mdpo-translator':
-                self._current_tcomment = comment.rstrip()
+                self._current_tcomment = comment
 
     def _process_command(self, text):
         original_command, comment = parse_mdpo_html_command(text)
@@ -304,7 +280,7 @@ class Po2Md:
     def _escape_translation(self, text):
         if self._aimg_title_inside_current_msgid:
             # escape '"' characters inside links and image titles
-            text = escape_links_titles(text)
+            text = polib.escape(text)
         return text
 
     def _translate_msgid(self, msgid, msgctxt, tcomment):
@@ -357,6 +333,7 @@ class Po2Md:
                     tcomment=self._current_tcomment,
                 ),
             )
+
         if self._inside_indented_codeblock:
             new_translation = ''
             for line in translation.splitlines():
@@ -393,9 +370,9 @@ class Po2Md:
                     code_end_string_escaped=self.code_end_string_escaped,
                     wikilink_start_string=self.wikilink_start_string,
                     wikilink_end_string=self.wikilink_end_string,
-                ).wrap(self._escape_translation(translation))
+                ).wrap(translation)
 
-                if self._inside_hblock or self._inside_table:
+                if self._inside_hblock or self._current_thead_aligns:
                     translation = translation.rstrip('\n')
 
         if translation.rstrip('\n'):
@@ -427,8 +404,13 @@ class Po2Md:
         ):
             return
 
-        if self._inside_quoteblock and (
-                not self._current_line or self._current_line[0] != '>'
+        if (
+            self._inside_quoteblock
+            and (not self._current_line or self._current_line[0] != '>')
+            and not self._current_thead_aligns
+            and block not in {
+                md4c.BlockType.TABLE, md4c.BlockType.THEAD, md4c.BlockType.TR,
+            }
         ):
             self._current_line += '> '
         if block is md4c.BlockType.P:
@@ -444,7 +426,7 @@ class Po2Md:
                 indent += '   ' * len(self._current_list_type)
 
             if details['fence_char'] is not None:
-                fence_chars = details['fence_char']*3
+                fence_chars = details['fence_char'] * 3
                 self._current_line += f'{indent}{fence_chars}'
                 if details['lang']:
                     self._current_line += details['lang'][0][1]
@@ -488,25 +470,26 @@ class Po2Md:
             self._current_list_type.append(['ol', []])
             self._ol_marks.append([0, details['mark_delimiter']])
         elif block is md4c.BlockType.HR:
+            if self._current_list_type and not self._current_line:
+                self._save_current_line()
+            indent = (
+                '   ' * len(self._current_list_type)
+                if not self._current_line.startswith(('- ', '> - ')) else ''
+            )
+            self._current_line += f'{indent}***'
+            self._save_current_line()
             if not self._inside_liblock:
-                self._current_line += '---\n\n'
-            else:
-                # inside lists, the separator '---' can't be used
-                self._current_line += '***'
+                if self._inside_quoteblock:
+                    self._current_line += f'{indent}>'
+                self._save_current_line()
         elif block is md4c.BlockType.TR:
             self._current_line += '   ' * len(self._current_list_type)
-            if self._current_line.startswith('>    '):
-                self._current_line = self._current_line.replace('> ', '')
+            if self._inside_quoteblock and self._current_thead_aligns:
+                self._current_line += '> '
         elif block is md4c.BlockType.TH:
-            if self._inside_quoteblock:
-                if not self._current_line.replace(' ', '') == '>':
-                    self._current_line = removesuffix(self._current_line, '> ')
             self._current_line += '| '
             self._current_thead_aligns.append(details['align'].value)
         elif block is md4c.BlockType.TD:
-            if self._inside_quoteblock:
-                if not self._current_line.replace(' ', '') == '>':
-                    self._current_line = removesuffix(self._current_line, '> ')
             self._current_line += '| '
         elif block is md4c.BlockType.QUOTE:
             if self._inside_liblock:
@@ -514,7 +497,6 @@ class Po2Md:
                 self._save_current_line()
             self._inside_quoteblock = True
         elif block is md4c.BlockType.TABLE:
-            self._inside_table = True
             if self._current_list_type and not self._inside_quoteblock:
                 self._save_current_line()
         elif block is md4c.BlockType.HTML:
@@ -575,10 +557,11 @@ class Po2Md:
             self._inside_indented_codeblock = False
         elif block is md4c.BlockType.H:
             self._save_current_msgid()
-            if not self._inside_quoteblock:
-                self._current_line += '\n'
+            if self._inside_quoteblock:
+                self._save_current_line()
+                self._current_line += '> '
             else:
-                self._current_line += '\n> '
+                self._current_line += '\n'
             self._save_current_line()
             if self._inside_quoteblock:
                 self._current_line += '> '
@@ -593,7 +576,7 @@ class Po2Md:
             self._current_list_type.pop()
             if self._inside_quoteblock:
                 self._current_line += '> '
-            if not self._ul_marks and self._outputlines[-1]:
+            if not self._ul_marks and self._outputlines[-1].split('\n')[-1]:
                 self._save_current_line()
         elif block is md4c.BlockType.OL:
             self._ol_marks.pop()
@@ -602,43 +585,29 @@ class Po2Md:
                 self._current_line += '> '
             if not self._ol_marks and self._outputlines[-1]:
                 self._save_current_line()
-        elif block is md4c.BlockType.TH or block is md4c.BlockType.TD:
+        elif block in {md4c.BlockType.TH, md4c.BlockType.TD}:
             self._save_current_msgid()
             self._current_line += ' '
         elif block is md4c.BlockType.TR:
-            if not self._current_thead_aligns:
-                self._current_line += '|'
-                self._save_current_line()
+            self._current_line += '|'
+            self._save_current_line()
         elif block is md4c.BlockType.THEAD:
             # build thead separator
             thead_separator = ''
             if self._inside_quoteblock:
-                _thead_split = re.split(r'[^\\](\|)', self._current_line)
-                if self._current_list_type:
-                    _thead_split = _thead_split[1:]
-                self._current_line += '|'
                 thead_separator += '> '
-            else:
-                self._current_line += '|'
-                _thead_split = re.split(r'[^\\](\|)', self._current_line)
-                if self._current_list_type:
-                    _thead_split = _thead_split[1:-1]
-            thead_separator += '| '
-
-            _antepenultimate_thead_i = len(_thead_split) - 2
-            for i, title in enumerate(_thead_split):
-                if (i % 2) != 0 or i > _antepenultimate_thead_i:
-                    continue
-                align = self._current_thead_aligns.pop(0)
-                sep_left = '-' if align in [0, 3] else ':'
-                sep_right = '-' if align in [0, 1] else ':'
-                thead_separator += f'{sep_left}-{sep_right}'
-                thead_separator += ' |'
-                if i < len(_thead_split) - 3:
-                    thead_separator += ' '
+            for align in self._current_thead_aligns:
+                if align == 0:
+                    thead_separator += '| --- '
+                elif align == 1:
+                    thead_separator += '| :-- '
+                elif align == 2:
+                    thead_separator += '| :-: '
+                else:
+                    thead_separator += '| --: '
 
             indent = '   ' * len(self._current_list_type)
-            self._current_line += f'\n{indent}{thead_separator}'
+            self._current_line += f'{indent}{thead_separator}|'
             self._save_current_line()
         elif block is md4c.BlockType.QUOTE:
             if self._outputlines[-1] == '>':
@@ -649,7 +618,7 @@ class Po2Md:
         elif block is md4c.BlockType.TABLE:
             if not self._inside_quoteblock and not self._current_list_type:
                 self._save_current_line()
-            self._inside_table = False
+            self._current_thead_aligns = []
         elif block is md4c.BlockType.HTML:
             self._inside_htmlblock = False
 
@@ -696,11 +665,10 @@ class Po2Md:
                         self._current_aspan_ref_target = target
                         break
             else:
-                for target, href, title in self._link_references:
+                for target, href, _ in self._link_references:
                     if href == self._current_aspan_href:
                         self._current_aspan_ref_target = target
                         break
-
         elif span is md4c.SpanType.CODE:
             self._inside_codespan = True
             self._codespan_start_index = len(self._current_msgid)-1
@@ -746,10 +714,11 @@ class Po2Md:
 
         if span is md4c.SpanType.A:
             if self._current_aspan_ref_target:  # referenced link
-                self._current_msgid += (
-                    f'[{self._current_aspan_text}]'
-                    f'[{self._current_aspan_ref_target}]'
-                )
+                self._current_msgid += f'[{self._current_aspan_text}]'
+                if self._current_aspan_ref_target != self._current_aspan_text:
+                    self._current_msgid += (
+                        f'[{self._current_aspan_ref_target}]'
+                    )
                 self._current_aspan_ref_target = None
             else:
                 if self._current_aspan_text == self._current_aspan_href:
@@ -782,7 +751,7 @@ class Po2Md:
             referenced_target, imgspan_title = (None, None)
             imgspan_src = details['src'][0][1]
             if details['title']:
-                imgspan_title = details['title'][0][1]
+                imgspan_title = polib.escape(details['title'][0][1])
                 for target, href, title in self._link_references:
                     if href == imgspan_src and title == imgspan_title:
                         referenced_target = target
@@ -803,13 +772,13 @@ class Po2Md:
                     img_markup += f' "{imgspan_title}"'
                 img_markup += ')'
 
-            self._current_imgspan = {}
-
             if self._inside_aspan:
                 self._current_aspan_text += img_markup
             else:
                 self._current_msgid += img_markup
 
+            self._current_imgspan = {}
+
     def text(self, block, text):
         # raise 'text' event
         if raise_skip_event(
