@@ -15,6 +15,7 @@ from mdpo.cli import (
     add_debug_option,
     add_encoding_arguments,
     add_pre_commit_option,
+    add_wrapwidth_argument,
     cli_codespan,
     parse_command_aliases_cli_arguments,
 )
@@ -46,7 +47,7 @@ def build_parser():
     )
     parser.add_argument(
         '-p', '--po-files', '--pofiles', metavar='POFILES', action='append',
-        nargs='*', dest='pofiles',
+        nargs='*', dest='pofiles', required=True,
         help='Glob matching a set of PO files from where to extract references'
              ' to make the replacements translating strings. This argument'
              ' can be passed multiple times.',
@@ -62,12 +63,7 @@ def build_parser():
         help='Saves the output content in a file whose path is specified at'
              ' this parameter.', metavar='PATH',
     )
-    parser.add_argument(
-        '-w', '--wrapwidth', dest='wrapwidth', default='80', type=str,
-        help='Maximum width rendering the Markdown output, when possible. If'
-             ' negative, \'0\' or \'inf\', the content will not be wrapped.',
-        metavar='N/inf',
-    )
+    add_wrapwidth_argument(parser, markup='md', default='80')
     add_encoding_arguments(parser)
     add_command_alias_argument(parser)
     add_debug_option(parser)
@@ -90,6 +86,9 @@ def parse_options(args):
         and opts.filepath_or_content
     ):
         filepath_or_content += opts.filepath_or_content[0]
+    if not filepath_or_content:
+        sys.stderr.write('Files or content to translate not specified\n')
+        sys.exit(1)
     opts.filepath_or_content = filepath_or_content
 
     opts.command_aliases = parse_command_aliases_cli_arguments(
